Index: tests/dartino_tests/test_suite_consumer.dart |
diff --git a/tests/fletch_tests/test_suite_consumer.dart b/tests/dartino_tests/test_suite_consumer.dart |
similarity index 75% |
rename from tests/fletch_tests/test_suite_consumer.dart |
rename to tests/dartino_tests/test_suite_consumer.dart |
index 07e688914bf3346dfb3660d2a88c7708e8aab682..bc2b95de629382045237fd3c6d917c511636fd0b 100644 |
--- a/tests/fletch_tests/test_suite_consumer.dart |
+++ b/tests/dartino_tests/test_suite_consumer.dart |
@@ -2,7 +2,7 @@ |
// for details. All rights reserved. Use of this source code is governed by a |
// BSD-style license that can be found in the LICENSE.md file. |
/// Command-line utility for helping testing fletch_test_suite.dart outside |
/// test.py. |
/// |
/// Example usage: |
@@ -17,15 +17,15 @@ |
/// |
/// cat messages.txt | \ |
/// ./third_party/bin/$OS/dart --packages=.packages/ \ |
-/// tests/fletch_tests/fletch_test_suite.dart | \ |
+/// tests/dartino_tests/dartino_test_suite.dart | \ |
/// ./third_party/bin/$OS/dart --packages=.packages \ |
-/// tests/fletch_tests/test_suite_consumer.dart |
-library fletch_tests.test_suite_consumer; |
+/// tests/dartino_tests/test_suite_consumer.dart |
+library dartino_tests.test_suite_consumer; |
import 'dart:io' show |
stdin; |
-import 'fletch_test_suite.dart' show |
+import 'dartino_test_suite.dart' show |
utf8Lines; |
import 'messages.dart' show |
@@ -2,7 +2,7 @@ |
// for details. All rights reserved. Use of this source code is governed by a |
// BSD-style license that can be found in the LICENSE.md file. |
-/// Command-line utility for helping testing fletch_test_suite.dart outside |
+/// Command-line utility for helping testing dartino_test_suite.dart outside |
/// test.py. |
/// |